@@ -558,7 +558,7 @@ value of texinfo-mode-hook."
    "end\\|"
    "enumerate\\|"
    "example\\|"
-   "f?table\\|"
+   "[fv]?table\\|"
    "flushleft\\|"
    "flushright\\|"
    "format\\|"
